@@ -215,7 +215,7 @@ class LiveRegionManager:
                 utts = message['content']
             else:
                 utts = message['labels'] + message['content']
-            speech.speakUtterances(utts)
+            speech.speak(utts)
 
             # set the last live obj to be announced
             self.lastliveobj = obj
@@ -279,7 +279,7 @@ class LiveRegionManager:
             #
             utterances.append(_('setting live region to off'))
 
-        speech.speakUtterances(utterances)
+        speech.speak(utterances)
 
     def goLastLiveRegion(self):
         """Move the caret to the last announced live region and speak the 
@@ -298,7 +298,7 @@ class LiveRegionManager:
             #
             speech.speak(_('no live message saved'))
         else:
-            speech.speakUtterances(self.msg_cache[-msgnum])
+            speech.speak(self.msg_cache[-msgnum])
 
     def setLivePolitenessOff(self):
         """User toggle to set all live regions to LIVE_OFF or back to their
@@ -346,13 +346,13 @@ class LiveRegionManager:
             # Toggle our flag
             self.monitoring = True  
 
-    def outputLiveRegionDescription(self, obj):
+    def generateLiveRegionDescription(self, obj, **args):
         """Used in conjuction with whereAmI to output description and 
         politeness of the given live region object"""
         objectid = self._getObjectId(obj)
         uri = self._script.bookmarks.getURIKey()
 
-        utterances = []
+        results = []
 
         # get the description if there is one.
         for relation in obj.getRelationSet():
@@ -360,7 +360,14 @@ class LiveRegionManager:
             if relationtype == pyatspi.RELATION_DESCRIBED_BY:
                 targetobj = relation.getTarget(0)
                 try:
-                    utterances.append(targetobj.queryText().getText(0, -1))
+                    # We will add on descriptions if they don't duplicate
+                    # what's already in the object's description.
+                    # See http://bugzilla.gnome.org/show_bug.cgi?id=568467
+                    # for more information.
+                    #
+                    description = targetobj.queryText().getText(0, -1)
+                    if description.strip() != obj.description.strip():
+                        results.append(description)
                 except NotImplemented:
                     pass
 
@@ -372,12 +379,13 @@ class LiveRegionManager:
             liveprioritystr = 'none'
 
         # We will only output useful information
-        # TODO: check for repeated descriptions
-        if utterances or liveprioritystr != 'none':
+        # 
+        if results or liveprioritystr != 'none':
             # Translators: output the politeness level
             #
-            utterances.append(_('politeness level %s') %liveprioritystr)
-            speech.speakUtterances(utterances)
+            results.append(_('politeness level %s') %liveprioritystr)
+
+        return results
 
     def matchLiveRegion(self, obj):
         """Predicate used to find a live region"""
@@ -453,7 +461,7 @@ class LiveRegionManager:
             speech.stop()
             # Note: we would like to use a different ACSS for alerts.  This work
             # should be done as part of bug #412656.
-            speech.speakUtterances(utts)
+            speech.speak(utts)
             return None
         else:
             return {'content':content, 'labels':labels}
